@@ -3,17 +3,24 @@
 %    Writes an ArrayOfVector to a NetCDF file for use with Arts.
 %    Array elements must be column vectors!
 %
-% FORMAT   arts_nc_write_arrayofvector(filename,v)
+% FORMAT   arts_nc_write_arrayofvector(filename, v, varargin)
 %        
-% IN    filename Name of NetCDF file.
-% IN    v        ArrayOfVector variable.
+% IN    filename  Name of NetCDF file.
+% IN    v         ArrayOfVector variable.
+% OPT   varargin  Cell array of name/value pair cells for global attributes
 
 % 2010-02-03   Created by Oliver Lemke.
 
-function arts_nc_write_arrayofvector (filename, v)
+function arts_nc_write_arrayofvector (filename, v, varargin)
 
 ncid = netcdf.create (filename, 'NC_CLOBBER');
 
+attributes = optargs( varargin, { [] } );
+
+if (~isempty(attributes))
+      addncattributes (ncid, attributes);
+end
+
 ndim = netcdf.defDim (ncid, 'nelem', length(v));
 
 vdims = zeros (length(v), 1, 'int32');
