@@ -37,6 +37,17 @@ I.ABS_LINES = [ ...
 'ABS_LINES_FORMAT is set to ''Arts''.'
 ];
 %-----------------------------------------------------------------------------
+Q.ABS_LINES_FLIMS = {};
+I.ABS_LINES_FLIMS = [ ...
+'Frequency limits when reading from input spectroscopic file.', ...
+'#   When *ABS_LINES_FORMAT* is set and is not equal to ''None'', this ',...
+'field matches the arguments *fmin* and *fmax* in ARTS reading routines ',...
+'for *abs_lines*. See e.g. *abs_linesReadFromJpl*. This field shall be a ',...
+'vector of length 2. If not set, default is [0,1e99].',...
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
+];
+%-----------------------------------------------------------------------------
 Q.ABS_LINES_FORMAT = {};
 I.ABS_LINES_FORMAT = [ ...
 'The format of spectroscopic data.', ...
