@@ -51,9 +51,9 @@ I.METHOD_PRMTRS = [ ...
 '# ',...
 '#*** DOIT ***',...
 '#   N_ZA_GRID       : ',...
-'#As the keyword arguments of *DoitAngularGridsSet*',...
+'#As the keyword arguments of *DoitAngularGridsSet*.',...
 '#   N_AA_GRID       : ',...
-'#As the keyword arguments of *DoitAngularGridsSet*',...
+'#As the keyword arguments of *DoitAngularGridsSet*.',...
 '#   ZA_GRID_OPT_FILE: ',...
 '#As the keyword arguments of *DoitAngularGridsSet*.', ...
 ' If no filename is given (""), equidistant grids are used for RT', ...
@@ -73,7 +73,13 @@ I.METHOD_PRMTRS = [ ...
 'If true, the internal intensity field of the cloud box is reset to the ',...
 'clear sky field for each frequency. Otherwise, this is done only for the ',...
 'the first frequency, and the previous solution field is used as starting ',...
-'point for subsequent frequencies.'
+'point for subsequent frequencies.',...
+'#   NORMALIZE       : ',...
+'#As the keyword argument *normalize* of *doit_i_fieldUpdateSeq1D*. ',...
+'Default is 0.',...
+'#   NORM_ERROR_THRESHOLD: ',...
+'#As the keyword argument *norm_error_threshold* of ',...
+'*doit_i_fieldUpdateSeq1D*. Must be set if NORMALIZE is an existing field.'
 ];
 %-----------------------------------------------------------------------------
 C.OPT_PROP_PART_AGENDA = {};
