@@ -153,7 +153,7 @@ H.SIDEBAND_RESPONSE = {};
 I.SIDEBAND_RESPONSE = [ ...
 'Matches the ARTS WSV with the same name or *sideband_response_multi*. ', ...
 'If the sensor response does not include a mixer and sideband filter, ', ...
-'this variable can be left as {}. If set, call of *sensor_responseBackend *',...
+'this variable can be left as {}. If set, call of *sensor_responseMixer*',...
 ' or *sensor_responseMultiMixerBackend* is added.', ...
 '#   Can be given either as the name of a XML file, or as a Matlab',...
 ' variable.'
