@@ -28,6 +28,7 @@ if strcmp( filename(length(filename)-2:end), '.gz')
 end
 
 fid = fopen (filename,'rt');
+cobj = onCleanup(@()fclose(fid));
 
 if fid == -1
   if ~strcmp (uncompressed_filename, '')
@@ -41,9 +42,11 @@ c = fgets (fid, 1);
 s = c;
 while ~feof (fid) && c ~= '>'
   c = fgets (fid, 1);
-  s = strcat (s, c);
+  s = [s c];
 end
 
+s = s(s ~= ' ');
+
 if ~strcmp (s, '<?xmlversion="1.0"?>')
   if ~strcmp (uncompressed_filename, '')
     delete (uncompressed_filename);
@@ -54,8 +57,6 @@ end
 %=== Parsing data tag
 result = xmlReadTag(fid, filename, '', '', 0, 0);
 
-fclose (fid);
-
 if ~strcmp (uncompressed_filename, '')
   delete (uncompressed_filename);
 end
