@@ -75,10 +75,18 @@
 %   ARTS (both versions):
 %     A number between 0 and 3, where 3 means highest level of verbosity.
 %----------------------------------------------------------------------------
+% LEGACY_MODE
+%
+% Include deprecated functions and settings. Used by some subsystems.
+%----------------------------------------------------------------------------
 % OUT
 %
 % Stream to log ordinary messages to. Used by some subsystems.
 %----------------------------------------------------------------------------
+% PYTHON
+%
+% Path to Python interpreter to use in relevant situations.
+%----------------------------------------------------------------------------
 % RAND_STATE
 %
 % Initialisation of random states (for rand and randn). Either NaN or an
@@ -98,6 +106,18 @@
 % The width, in number of characters, of the Matlab window.
 % Used by the function *out* to make a frame around screen output.
 %----------------------------------------------------------------------------
+% STRICT_ASSERT
+% 
+% Some parts of atmlab performs quite strict checks of input arguments and
+% data. Such asserts and checks can in some cases take a significant fraction
+% of the calculation time in a function (or even dominate the time) and, to
+% allow faster calculations, some functions use this flag to possibly
+% deactivate the checks. Default is true and the checks are performed. If you
+% have a stable set-up, you can set this field to false and potentially improve
+% the calculation speed. That is, if you are sure that the assertions
+% are not needed (only applies to assertions in "if amtlab('STRICT_ASSERT')"
+% environments), then set atmlab('STRICT_ASSERT')=false;
+%----------------------------------------------------------------------------
 % VERBOSITY
 % 
 % The verbosity of Atmlab functions.  
@@ -110,18 +130,15 @@
 % WORK_AREA
 % 
 % A folder to be used for calculations outside Matlab. For each calculation
-% session, a folder is created in the given folder with name TmpXXXXXX where
-% XXXXXX is an integer with up to 6 digits. Atmlab tries to keep the given
-% folder clean by removing the temporary folders when ready, but if there
-% is a crash the temporary folder will not be removed. The temporary folders
-% are not re-used and before the debugging is finished a high number of
-% folders can be created in the work area and it can be a good idea to remove
-% old temporary folders.
-%    The full path shall be given. A normal choice for work area on Unix type 
-% platforms is '/tmp'.
-%    The work area is primarily used for forward model calculations, but
-% there could be other applications.
-
+% session, a temporary folder is created in the given folder. Atmlab tries to
+% keep the given folder clean by removing the temporary folders when ready, but
+% if there is a crash the temporary folder can occasionaly be left. The
+% temporary folders are not re-used and it can be a good idea to now and then
+% remove old temporary folders. 
+% The full path shall be given. A normal choice for work area on Unix type
+% platforms is '/tmp'. The work area is primarily used for forward model
+% calculations, but there could be other applications.
+% ----------------------------------------------------------------------------
 
 % 2003-07-06   Created by Patrick Eriksson.
 
@@ -151,7 +168,7 @@ if length(varargin) == 2
       if isempty(nr)
         nr = 0;
       else
-        nr = str2num( nr );
+        nr = str2double( nr );
       end
       %
       rand( 'state', sum(100*clock) + nr );
@@ -171,7 +188,7 @@ end
 %
 return
 
-
+end
   
 %---------------------------------------------------------------------------
 function A = atmlab_defs
@@ -184,9 +201,16 @@ A.ATMLAB_DATA_PATH  = NaN;
 A.DEBUG             = false;
 A.ERR               = 2;
 A.FMODEL_VERBOSITY  = 0;
+A.LEGACY_MODE       = false;
 A.OUT               = 1;
+[u,X] = system('type -p python');
+A.PYTHON            = strtrim(X);
 A.RAND_STATE        = NaN;
 A.SCREEN_WIDTH      = 70;
 A.SITE              = NaN;
+A.STRICT_ASSERT     = true;
 A.VERBOSITY         = 1;
 A.WORK_AREA         = tempdir();
+A.STRICT_ASSERT     = true;
+
+end
