@@ -45,7 +45,7 @@ O      = oem;
 %
 O.itermethod = 'GN';
 O.stop_dx    = 0.01;
-O.maxiter    = 10;
+O.maxiter    = 20;
 %
 O.cost       = true;
 O.e          = true; 
@@ -61,39 +61,50 @@ O.yf         = true;
 
 %- General 
 %
-Q.INCLUDES            = { fullfile( arts_includes, 'general.arts' ), ...
-                          fullfile( arts_includes, 'continua.arts' ) };
+Q.INCLUDES            = { fullfile( 'ARTS_INCLUDES', 'general.arts' ), ...
+                          fullfile( 'ARTS_INCLUDES', 'agendas.arts' ), ...
+                          fullfile( 'ARTS_INCLUDES', 'continua.arts' ), ...
+                          fullfile( 'ARTS_INCLUDES', 'planet_earth.arts' ) };
 Q.ATMOSPHERE_DIM      = 1;
 Q.STOKES_DIM          = 1;
 
 %- Atmosphere
 %
-Q.R_GEOID             = constants( 'EARTH_RADIUS' );
 Q.Z_SURFACE           = 0;
 Q.P_GRID              = z2p_simple( -250:250:90e3 )';
 %
-Q.RAW_ATMOSPHERE      = fullfile( arts_xmldata_path, 'atmosphere', ...
-                                              'fascod', 'midlatitude-winter' );
+Q.RAW_ATMOSPHERE      = fullfile( arts_xmldata_path, 'planets', 'Earth', ...
+                        'Fascod', 'midlatitude-winter', 'midlatitude-winter' );
 Q.CLOUDBOX_DO         = false;
 
+
+%= Define agendas
+%
+Q.PPATH_AGENDA               = { 'ppath_agenda__FollowSensorLosPath'   };
+Q.PPATH_STEP_AGENDA          = { 'ppath_step_agenda__GeometricPath'    };
+Q.BLACKBODY_RADIATION_AGENDA = { 'blackbody_radiation_agenda__Planck'  };
+Q.IY_SURFACE_AGENDA          = { 'iy_surface_agenda__UseSurfaceRtprop' };
+Q.IY_MAIN_AGENDA             = { 'iy_main_agenda__Emission'            };
+
+
+%- Exclude cosmic background radiation. A relative change of the spectrum
+%- corresponds then to a relative change of the ozone profile.
+%
+Q.IY_SPACE_AGENDA     = { 'Ignore(rtp_los)',  'Ignore(rtp_pos)', ...
+                          'nelemGet(nrows,f_grid)', ...
+                          'Copy(ncols,stokes_dim)', ...
+                          'MatrixSetConstant(iy,nrows,ncols,0)' };
+
+
 %- RTE
 %
 Q.YCALC_WSMS          = { 'yCalc' };
 %
 Q.PPATH_LMAX          = 250;
-Q.PPATH_STEP_AGENDA   = { 'ppath_stepGeometric' };
-Q.Y_UNIT              = 'RJBT';
+Q.IY_UNIT              = 'RJBT';
 %
 Q.SENSOR_LOS          = 70;
-Q.SENSOR_POS          = Q.R_GEOID + Q.Z_SURFACE;
-
-%- Exclude cosmic background radiation. A relative change of the spectrum
-%- corresponds then to a relative change of the ozone profile.
-%
-Q.IY_SPACE_AGENDA     = { 'Ignore(rte_los)',  'Ignore(rte_pos)', ...
-                          'nelemGet(nrows,f_grid)', ...
-                          'Copy(ncols,stokes_dim)', ...
-                          'MatrixSetConstant(iy,nrows,ncols,0)' };
+Q.SENSOR_POS          = Q.Z_SURFACE;
 
 
 %- Frequency, spectrometer and pencil beam antenna
@@ -143,23 +154,11 @@ Q.ABS_SPECIES(2).TAG      = { 'O3' };
 Q.ABS_SPECIES(2).RETRIEVE = true;
 Q.ABS_SPECIES(2).GRIDS    = { z2p_simple( 0e3:1e3:90e3 )', [], [] };
 Q.ABS_SPECIES(2).UNIT     = 'vmr';
-if 1
-  Q.ABS_SPECIES(2).SX     = covmat1d_from_cfun( Q.ABS_SPECIES(2).GRIDS{1}, ...
+Q.ABS_SPECIES(2).MINMAX   = 1e-12;
+Q.ABS_SPECIES(2).SX       = covmat1d_from_cfun( Q.ABS_SPECIES(2).GRIDS{1}, ...
                                     2e-6, 'lin', 0.2, 0.00, @log10 ) + ...
                             covmat1d_from_cfun( Q.ABS_SPECIES(2).GRIDS{1}, ...
                                   0.5e-6, 'lin', 0.5, 0.00, @log10 );
-else
-  arts_xmldata_path = atmlab( 'ARTS_XMLDATA_PATH' );
-  O3 = xmlLoad( fullfile( arts_xmldata_path, 'atmosphere', 'fascod', ...
-                                                         'tropical.O3.xml' ) );
-  Q.ABS_SPECIES(2).SX     = covmat1d_from_cfun( Q.ABS_SPECIES(2).GRIDS{1}, ...
-                            [ O3.grids{1}, 0.5*O3.data ], ...
-                                              'lin', 0.2, 0.00, @log10 ) + ...
-                            covmat1d_from_cfun( Q.ABS_SPECIES(2).GRIDS{1}, ...
-                            [ O3.grids{1}, 0.1*O3.data ], ...
-                                              'lin', 0.5, 0.00, @log10 );
-end
-
 
 
 %----------------------------------------------------------------------------
