@@ -9,7 +9,7 @@ function command = pscoast(file,in)
 % OUT   command   %s              string command to be used in system call
 %
 % Created by Salomon Eliasson
-% $Id: pscoast.m 7157 2011-09-18 10:38:57Z seliasson $
+% $Id: pscoast.m 8362 2013-04-20 18:30:35Z seliasson $
 
 pscoast = sprintf('pscoast -R -J');
 
@@ -20,7 +20,7 @@ pscoast = sprintf('%s -O -K',pscoast);
 
 % set the minimal area of features to plot
 if isfield(in,'features')
-    pscoast = sprintf('%s -A%f',pscoast,in.features);
+    pscoast = sprintf('%s -A%g',pscoast,in.features);
 end
 
 if isfield(in,'resolution')
@@ -36,7 +36,7 @@ end
 
 %Draw coastlines. Append attributes [Defaults: width = 1, color = black, texture = solid].
 if isfield(in,'width')
-    pscoast = sprintf('%s -W%fp',pscoast,in.width);
+    pscoast = sprintf('%s -W%gp',pscoast,in.width);
 else pscoast = sprintf('%s -W',pscoast);
 end
 if isfield(in,'color') %for coast
